"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryFunctions = exports.deleteFunction = exports.updateFunction = exports.getFunction = exports.createFunction = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const timestamp_2 = require("@wix/sdk-runtime/transformations/timestamp");
const field_mask_1 = require("@wix/sdk-runtime/transformations/field-mask");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveWixFunctionsApiV1FunctionsUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/_api/functions/v1/functions',
                destPath: '/v1/functions',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/functions/v1/functions',
                destPath: '/v1/functions',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_functions_functions';
/** Creates a function. */
function createFunction(payload) {
    function __createFunction({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'function.createdDate' },
                    { path: 'function.updatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.functions.v1.function',
            method: 'POST',
            methodFqn: 'wix.functions.api.v1.Functions.CreateFunction',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsApiV1FunctionsUrl({
                protoPath: '/v1/functions',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'function.createdDate' },
                        { path: 'function.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __createFunction;
}
exports.createFunction = createFunction;
/** Retrieves a function. */
function getFunction(payload) {
    function __getFunction({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.v1.function',
            method: 'GET',
            methodFqn: 'wix.functions.api.v1.Functions.GetFunction',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsApiV1FunctionsUrl({
                protoPath: '/v1/functions/{functionId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'function.createdDate' },
                        { path: 'function.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getFunction;
}
exports.getFunction = getFunction;
/**
 * Updates a function.
 *
 * Each time the function is updated,
 * `revision` increments by 1.
 * The existing `revision` must be passed when updating the function.
 * This ensures you're working with the latest version of the function
 * and prevents unintended overwrites.
 */
function updateFunction(payload) {
    function __updateFunction({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: field_mask_1.transformSDKFieldMaskToRESTFieldMask,
                paths: [{ path: 'fieldMask' }],
            },
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'function.createdDate' },
                    { path: 'function.updatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.functions.v1.function',
            method: 'PATCH',
            methodFqn: 'wix.functions.api.v1.Functions.UpdateFunction',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsApiV1FunctionsUrl({
                protoPath: '/v1/functions/{function.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'function.createdDate' },
                        { path: 'function.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updateFunction;
}
exports.updateFunction = updateFunction;
/**
 * Deletes a function.
 *
 * Deleting a function permanently removes it from the Function List
 * in the site dashboard.
 */
function deleteFunction(payload) {
    function __deleteFunction({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.v1.function',
            method: 'DELETE',
            methodFqn: 'wix.functions.api.v1.Functions.DeleteFunction',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsApiV1FunctionsUrl({
                protoPath: '/v1/functions/{functionId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __deleteFunction;
}
exports.deleteFunction = deleteFunction;
/**
 * Retrieves a list of functions, given the provided paging, filtering, and sorting.
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 */
function queryFunctions(payload) {
    function __queryFunctions({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.v1.function',
            method: 'POST',
            methodFqn: 'wix.functions.api.v1.Functions.QueryFunctions',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsApiV1FunctionsUrl({
                protoPath: '/v1/functions/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'functions.createdDate' },
                        { path: 'functions.updatedDate' },
                    ],
                },
            ]),
            fallback: [
                {
                    method: 'POST',
                    url: resolveWixFunctionsApiV1FunctionsUrl({
                        protoPath: '/v1/functions/query',
                        data: payload,
                        host,
                    }),
                    data: payload,
                },
            ],
        };
        return metadata;
    }
    return __queryFunctions;
}
exports.queryFunctions = queryFunctions;
//# sourceMappingURL=functions-v1-function-functions.http.js.map