import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformSDKTimestampToRESTTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformSDKFieldMaskToRESTFieldMask } from '@wix/sdk-runtime/transformations/field-mask';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixFunctionsApiV1FunctionsUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/_api/functions/v1/functions',
                destPath: '/v1/functions',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/functions/v1/functions',
                destPath: '/v1/functions',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_functions_functions';
/** Creates a function. */
export function createFunction(payload) {
    function __createFunction({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'function.createdDate' },
                    { path: 'function.updatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.functions.v1.function',
            method: 'POST',
            methodFqn: 'wix.functions.api.v1.Functions.CreateFunction',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsApiV1FunctionsUrl({
                protoPath: '/v1/functions',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'function.createdDate' },
                        { path: 'function.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __createFunction;
}
/** Retrieves a function. */
export function getFunction(payload) {
    function __getFunction({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.v1.function',
            method: 'GET',
            methodFqn: 'wix.functions.api.v1.Functions.GetFunction',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsApiV1FunctionsUrl({
                protoPath: '/v1/functions/{functionId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'function.createdDate' },
                        { path: 'function.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getFunction;
}
/**
 * Updates a function.
 *
 * Each time the function is updated,
 * `revision` increments by 1.
 * The existing `revision` must be passed when updating the function.
 * This ensures you're working with the latest version of the function
 * and prevents unintended overwrites.
 */
export function updateFunction(payload) {
    function __updateFunction({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKFieldMaskToRESTFieldMask,
                paths: [{ path: 'fieldMask' }],
            },
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'function.createdDate' },
                    { path: 'function.updatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.functions.v1.function',
            method: 'PATCH',
            methodFqn: 'wix.functions.api.v1.Functions.UpdateFunction',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsApiV1FunctionsUrl({
                protoPath: '/v1/functions/{function.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'function.createdDate' },
                        { path: 'function.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updateFunction;
}
/**
 * Deletes a function.
 *
 * Deleting a function permanently removes it from the Function List
 * in the site dashboard.
 */
export function deleteFunction(payload) {
    function __deleteFunction({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.v1.function',
            method: 'DELETE',
            methodFqn: 'wix.functions.api.v1.Functions.DeleteFunction',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsApiV1FunctionsUrl({
                protoPath: '/v1/functions/{functionId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __deleteFunction;
}
/**
 * Retrieves a list of functions, given the provided paging, filtering, and sorting.
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 */
export function queryFunctions(payload) {
    function __queryFunctions({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.v1.function',
            method: 'POST',
            methodFqn: 'wix.functions.api.v1.Functions.QueryFunctions',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsApiV1FunctionsUrl({
                protoPath: '/v1/functions/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'functions.createdDate' },
                        { path: 'functions.updatedDate' },
                    ],
                },
            ]),
            fallback: [
                {
                    method: 'POST',
                    url: resolveWixFunctionsApiV1FunctionsUrl({
                        protoPath: '/v1/functions/query',
                        data: payload,
                        host,
                    }),
                    data: payload,
                },
            ],
        };
        return metadata;
    }
    return __queryFunctions;
}
//# sourceMappingURL=functions-v1-function-functions.http.js.map