import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { FunctionCreatedEnvelope, FunctionDeletedEnvelope, FunctionUpdatedEnvelope, FunctionsQueryBuilder, UpdateFunction, _Function, _FunctionNonNullableFields } from './functions-v1-function-functions.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createFunction(httpClient: HttpClient): CreateFunctionSignature;
interface CreateFunctionSignature {
    /**
     * Creates a function.
     * @param - Function to create.
     * @returns The created function.
     */
    (_function?: _Function | undefined): Promise<_Function & _FunctionNonNullableFields>;
}
export declare function getFunction(httpClient: HttpClient): GetFunctionSignature;
interface GetFunctionSignature {
    /**
     * Retrieves a function.
     * @param - ID of the function to retrieve.
     * @returns The requested function.
     */
    (functionId: string): Promise<_Function & _FunctionNonNullableFields>;
}
export declare function updateFunction(httpClient: HttpClient): UpdateFunctionSignature;
interface UpdateFunctionSignature {
    /**
     * Updates a function.
     *
     * Each time the function is updated,
     * `revision` increments by 1.
     * The existing `revision` must be passed when updating the function.
     * This ensures you're working with the latest version of the function
     * and prevents unintended overwrites.
     * @param - Function ID.
     * @returns Updated function.
     */
    (_id: string | null, _function?: UpdateFunction | undefined): Promise<_Function & _FunctionNonNullableFields>;
}
export declare function deleteFunction(httpClient: HttpClient): DeleteFunctionSignature;
interface DeleteFunctionSignature {
    /**
     * Deletes a function.
     *
     * Deleting a function permanently removes it from the Function List
     * in the site dashboard.
     * @param - ID of the function to delete.
     */
    (functionId: string): Promise<void>;
}
export declare function queryFunctions(httpClient: HttpClient): QueryFunctionsSignature;
interface QueryFunctionsSignature {
    /**
     * Retrieves a list of functions, given the provided paging, filtering, and sorting.
     *
     * To learn about working with _Query_ endpoints, see
     * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
     * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
     * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
     */
    (): FunctionsQueryBuilder;
}
export declare const onFunctionCreated: EventDefinition<FunctionCreatedEnvelope, "wix.functions.v1.function_created">;
export declare const onFunctionDeleted: EventDefinition<FunctionDeletedEnvelope, "wix.functions.v1.function_deleted">;
export declare const onFunctionUpdated: EventDefinition<FunctionUpdatedEnvelope, "wix.functions.v1.function_updated">;
export { ActionEvent, ActivationStatus, BaseEventMetadata, CreateFunctionRequest, CreateFunctionResponse, CreateFunctionResponseNonNullableFields, CursorPaging, CursorPagingMetadata, CursorQuery, CursorQueryPagingMethodOneOf, Cursors, DeleteFunctionRequest, DeleteFunctionResponse, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, FieldAndCount, FunctionCreatedEnvelope, FunctionDeletedEnvelope, FunctionUpdatedEnvelope, FunctionsQueryBuilder, FunctionsQueryResult, GetFunctionRequest, GetFunctionResponse, GetFunctionResponseNonNullableFields, IdentificationData, IdentificationDataIdOneOf, ListValuesByFieldRequest, ListValuesByFieldResponse, MessageEnvelope, QueryFunctionsRequest, QueryFunctionsResponse, QueryFunctionsResponseNonNullableFields, RestoreInfo, SortOrder, Sorting, UpdateFunction, UpdateFunctionRequest, UpdateFunctionResponse, UpdateFunctionResponseNonNullableFields, WebhookIdentityType, _Function, _FunctionNonNullableFields, } from './functions-v1-function-functions.universal.js';
