import { renameKeysFromRESTResponseToSDKResponse } from '@wix/sdk-runtime/rename-all-nested-keys';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { EventDefinition } from '@wix/sdk-types';
import { createFunction as universalCreateFunction, deleteFunction as universalDeleteFunction, getFunction as universalGetFunction, queryFunctions as universalQueryFunctions, updateFunction as universalUpdateFunction, } from './functions-v1-function-functions.universal.js';
export const __metadata = { PACKAGE_NAME: '@wix/functions' };
export function createFunction(httpClient) {
    return (_function) => universalCreateFunction(_function, 
    // @ts-ignore
    { httpClient });
}
export function getFunction(httpClient) {
    return (functionId) => universalGetFunction(functionId, 
    // @ts-ignore
    { httpClient });
}
export function updateFunction(httpClient) {
    return (_id, _function) => universalUpdateFunction(_id, _function, 
    // @ts-ignore
    { httpClient });
}
export function deleteFunction(httpClient) {
    return (functionId) => universalDeleteFunction(functionId, 
    // @ts-ignore
    { httpClient });
}
export function queryFunctions(httpClient) {
    return () => universalQueryFunctions(
    // @ts-ignore
    { httpClient });
}
export const onFunctionCreated = EventDefinition('wix.functions.v1.function_created', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onFunctionDeleted = EventDefinition('wix.functions.v1.function_deleted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'undefined.createdDate' },
            { path: 'undefined.updatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onFunctionUpdated = EventDefinition('wix.functions.v1.function_updated', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export { ActivationStatus, SortOrder, WebhookIdentityType, } from './functions-v1-function-functions.universal.js';
//# sourceMappingURL=functions-v1-function-functions.public.js.map