"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryFunctions = exports.deleteFunction = exports.updateFunction = exports.getFunction = exports.createFunction = exports.WebhookIdentityType = exports.SortOrder = exports.ActivationStatus = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const query_builder_1 = require("@wix/sdk-runtime/query-builder");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixFunctionsV1Function = __importStar(require("./functions-v1-function-functions.http.js"));
var ActivationStatus;
(function (ActivationStatus) {
    /** Activation status is unknown. */
    ActivationStatus["UNKNOWN_STATUS"] = "UNKNOWN_STATUS";
    /** Function is activated. */
    ActivationStatus["ACTIVE"] = "ACTIVE";
    /** Function is deactivated. */
    ActivationStatus["INACTIVE"] = "INACTIVE";
    /** Function is saved but has never been activated. */
    ActivationStatus["DRAFT"] = "DRAFT";
})(ActivationStatus || (exports.ActivationStatus = ActivationStatus = {}));
var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (exports.SortOrder = SortOrder = {}));
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
/**
 * Creates a function.
 * @param _function - Function to create.
 * @public
 * @documentationMaturity preview
 * @requiredField function
 * @requiredField function.appId
 * @requiredField function.functionExtensionId
 * @permissionId FUNCTIONS.FUNCTION_CREATE
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @applicableIdentity APP
 * @returns The created function.
 * @fqn wix.functions.api.v1.Functions.CreateFunction
 */
async function createFunction(_function) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        function: _function,
    });
    const reqOpts = ambassadorWixFunctionsV1Function.createFunction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)?.function;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { function: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_function']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.createFunction = createFunction;
/**
 * Retrieves a function.
 * @param functionId - ID of the function to retrieve.
 * @public
 * @documentationMaturity preview
 * @requiredField functionId
 * @permissionId FUNCTIONS.FUNCTION_READ
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @applicableIdentity APP
 * @returns The requested function.
 * @fqn wix.functions.api.v1.Functions.GetFunction
 */
async function getFunction(functionId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        functionId: functionId,
    });
    const reqOpts = ambassadorWixFunctionsV1Function.getFunction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)?.function;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { functionId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['functionId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getFunction = getFunction;
/**
 * Updates a function.
 *
 * Each time the function is updated,
 * `revision` increments by 1.
 * The existing `revision` must be passed when updating the function.
 * This ensures you're working with the latest version of the function
 * and prevents unintended overwrites.
 * @param _id - Function ID.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField function
 * @requiredField function.revision
 * @permissionId FUNCTIONS.FUNCTION_UPDATE
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @applicableIdentity APP
 * @returns Updated function.
 * @fqn wix.functions.api.v1.Functions.UpdateFunction
 */
async function updateFunction(_id, _function) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        function: { ..._function, id: _id },
    });
    const reqOpts = ambassadorWixFunctionsV1Function.updateFunction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)?.function;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: { function: '$[1]' },
            explicitPathsToArguments: { 'function.id': '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id', '_function']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.updateFunction = updateFunction;
/**
 * Deletes a function.
 *
 * Deleting a function permanently removes it from the Function List
 * in the site dashboard.
 * @param functionId - ID of the function to delete.
 * @public
 * @documentationMaturity preview
 * @requiredField functionId
 * @permissionId FUNCTIONS.FUNCTION_DELETE
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @applicableIdentity APP
 * @fqn wix.functions.api.v1.Functions.DeleteFunction
 */
async function deleteFunction(functionId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        functionId: functionId,
    });
    const reqOpts = ambassadorWixFunctionsV1Function.deleteFunction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { functionId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['functionId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.deleteFunction = deleteFunction;
/**
 * Retrieves a list of functions, given the provided paging, filtering, and sorting.
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 * @public
 * @documentationMaturity preview
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @permissionId FUNCTIONS.FUNCTION_READ
 * @applicableIdentity APP
 * @fqn wix.functions.api.v1.Functions.QueryFunctions
 */
function queryFunctions() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    return (0, query_builder_1.queryBuilder)({
        func: async (payload) => {
            const reqOpts = ambassadorWixFunctionsV1Function.queryFunctions(payload);
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, {}];
            return (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data }) => {
            const transformedData = (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(data);
            return {
                items: transformedData?.functions,
                pagingMetadata: transformedData?.pagingMetadata,
            };
        },
        errorTransformer: (err) => {
            const transformedError = (0, transform_error_1.transformError)(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'CURSOR',
        transformationPaths: {},
    });
}
exports.queryFunctions = queryFunctions;
//# sourceMappingURL=functions-v1-function-functions.universal.js.map